# pygame example

This directory contains a cross-platform application that demonstrates how to integrate AccessKit with the pygame library.

## Prerequisites

- Python 3.8 or higher
- A virtual environment: `python -m venv .venv` (activating it will vary based on your platform)
- `pip install -r requirements.txt` 

## How to run

```bash
python hello_world.py
```
